@@ -1,6 +1,10 @@
 package Bundle::Slash;
 
-$Bundle::Slash::VERSION = '2.32';
+#
+# $Id: Slash.pm,v 1.29 2004/04/09 15:00:29 pudge Exp $
+#
+
+$Bundle::Slash::VERSION = '2.34';
 
 1;
 
@@ -43,6 +47,8 @@ HTML::FormatText        - ditto
 
 HTML::TokeParser
 
+HTML::ElementTable	- required by HTML::CalendarMonth
+
 HTML::CalendarMonth	- used for Events plugin
 
 Mail::Sendmail
@@ -61,6 +67,8 @@ Date::Parse		- TimeDate
 
 Date::Manip             - Still needed, but only in utils/
 
+Bit::Vector		- required by Date::Calc
+
 Date::Calc		- Use sparingly, only when necessary
 
 Time::ParseDate         - Time-modules; Needed for Schedule::Cron
@@ -69,6 +77,8 @@ Schedule::Cron
 
 XML::Parser
 
+Test::Manifest		- required by XML::RSS
+
 XML::RSS
 
 XML::Simple
@@ -81,20 +91,28 @@ Bundle::DBD::mysql	- ???
 
 DBIx::Password
 
-Apache::Test
-
 Apache::DBI
 
-Apache::Request		- libapreq; also includes Apache::Cookie
+Apache::Test		- may need to put Apache's 'httpd' and 'apxs' into $PATH before installing
+
+Apache::Cookie		- may need to put Apache's 'httpd' and 'apxs' into $PATH before installing
+
+Apache::Request		- libapreq
 
 AppConfig		- Should be installed with TT, but sometimes not?
 
 Template		- Template Toolkit
 
+LWP::Parallel
+
 
 =head1 DESCRIPTION
 
 mod_perl must be installed by hand, because of the special configuration
 required for it.
 
+Optional but recommended modules include:  Cache::Memcached Silly::Werder
+GD GD::Text Apache::SSI Apache::RegistryFilter
+
+
 =cut
